<?php
declare(strict_types=1);

namespace Catequil\Webshop\Filter;

use Catequil\Webshop\Model\WebshopInterface;
use Catequil\Webshop\Service\WebshopServiceInterface;
use Laminas\Filter\FilterInterface;
use function intval;
use function is_numeric;
use function is_string;

/**
 * Class WebshopFilter
 *
 * @package Catequil\Webshop\Filter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-webshop
 */
final class WebshopFilter implements FilterInterface
{
    private WebshopServiceInterface $webshops;

    /**
     * @param WebshopServiceInterface $webshops
     */
    public function __construct(WebshopServiceInterface $webshops)
    {
        $this->webshops = $webshops;
    }

    /**
     * @param int|string|null $value
     * @return WebshopInterface|null
     */
    public function filter($value): ?WebshopInterface
    {
        if (empty($value)) {
            return null;
        }

        return is_string($value) && is_numeric($value)
            ? $this->webshops->findById(intval($value))
            : $this->webshops->findByDomain($value);
    }
}